<?php

/**
 * @encoding     UTF-8
 * @package      WordPress Demo Content Manager
 * @link         https://codecanyon.net/item/wordpress-demo-content-manager/20669604
 * @copyright    Copyright (C) 2018 Torbara (http://torbara.com). All rights reserved.
 * @license      Envato Standard License http://themeforest.net/licenses/standard?ref=torbara
 * @author       Vladislav Dolgolenko <vladislavdolgolenko.com>
 * @support      <help@vladislavdolgolenko.com>
 */

namespace DM\AjaxControllers;

use DM\Processing\Installer;
use DM\Processing\Activator;
use DM\Processing\Creator;
use DM\Processing\UploadDemo;
use DM\Processing\Deploying;
use DM\Processing\MakeZip;
use DM\Manager;
use DM\Processing\Statuses;
use DM\Log;

class Processes implements \DM\WPObjects\EventManager\ListenerInterface
{
    public $register_processes = array(
        Installer::PROCESS_ID => '\DM\Processing\Installer',
        Activator::PROCESS_ID => '\DM\Processing\Activator',
        Creator::PROCESS_ID => '\DM\Processing\Creator',
        UploadDemo::PROCESS_ID => '\DM\Processing\UploadDemo',
        Deploying::PROCESS_ID => '\DM\Processing\Deploying',
        MakeZip::PROCESS_ID => '\DM\Processing\MakeZip'
    );
    
    public function attach()
    {
        \add_action( 'wp_ajax_dm_processing', array($this, 'processing'));
        \add_action( 'wp_ajax_dm_aborting', array($this, 'aborting'));
        \add_action( 'wp_ajax_dm_kill', array($this, 'kill'));
    }
    
    public function detach()
    {
        \remove_action( 'wp_ajax_dm_processing', array($this, 'processing'));
        \remove_action( 'wp_ajax_dm_aborting', array($this, 'aborting'));
        \remove_action( 'wp_ajax_dm_kill', array($this, 'kill'));
    }
    
    public function processing()
    {
        $process_class_name = $this->getProcessClassName();
        $Manager = Manager::getInstance();
        $Statuses = Statuses::getInstance();
        
        // Do not start when now processing
        if ($Statuses->isProcessing() === true) {
            die('');
        }
        
        // Do not start another process if another is not ended.
        if ($Statuses->getProcessId() && $Statuses->getProcessId() !== $this->getProcessName()) {
            die('');
        }
        
        $Statuses->createPID();

        $Log = new Log();
        $Installer = new $process_class_name($Log);
        
        try {

            $proessing_demo_id = $Statuses->getProcessingDemoId();
            if ($proessing_demo_id) {
                $demo_id = $proessing_demo_id;
            } else if (isset($_POST['demo_id']) && $_POST['demo_id']) {
                $demo_id = sanitize_text_field($_POST['demo_id']);
            } else {
                throw new \Exception('Process error: not undefined demo content');
            }

            $Demo = $Manager->initDemoByGlobalId($demo_id);
            if (!$Demo) {
                throw new \Exception('Process error: demo content not found');
            }

            $Installer->setDemo($Demo);
            $Installer->processing();

        } catch (\Exception $e) {

            status_header( 501 );
            $Log->addLog($e->getMessage(), true);

        }
        
        $Statuses->endPID();

        die();
    }
    
    public function aborting()
    {
        $process_class_name = $this->getProcessClassName();
        $Manager = Manager::getInstance();
        $Statuses = Statuses::getInstance();
        
        // Do not start when now processing
        if ($Statuses->isProcessing() === true) {
            die('');
        }
        
        // Do not start another process if another is not ended.
        if ($Statuses->getProcessId() && $Statuses->getProcessId() !== $this->getProcessName()) {
            die('');
        }
        
        $Statuses->createPID();

        $Log = new Log();
        $Installer = new $process_class_name($Log);
        
        try {

            $proessing_demo_id = $Statuses->getProcessingDemoId();
            if ($proessing_demo_id) {
                $demo_id = $proessing_demo_id;
            } else if (isset($_POST['demo_id']) && $_POST['demo_id']) {
                $demo_id = sanitize_text_field($_POST['demo_id']);
            } else {
                throw new \Exception('Process error: not undefined demo content');
            }

            $Demo = $Manager->initDemoByGlobalId($demo_id);
            if (!$Demo) {
                throw new \Exception('UnInstallation error: demo content not found');
            }

            $Installer->setDemo($Demo);
            $Installer->aborting();
            

        } catch (\Exception $e) {

            status_header( 501 );
            $Log->addLog($e->getMessage(), true);

        }
        
        $Statuses->endPID();

        die();
    }
    
    public function kill()
    {
        $Statuses = Statuses::getInstance();
        $Statuses->clean();
        $Statuses->endPID();
        
        die('');
    }

    protected function getProcessClassName()
    {
        $process = $this->getProcessName();
        if (!$process) {
            die('');
        }
        
        if (!in_array($process, array_keys($this->register_processes))) {
            die('');
        }
        
        return $this->register_processes[$process];
    }
    
    protected function getProcessName()
    {
        if (!isset($_POST['process']) || !$_POST['process']) {
            return false;
        }
        
        return sanitize_text_field( $_POST['process'] );
    }
}


