<?php

/**
 * @encoding     UTF-8
 * @package      WordPress Demo Content Manager
 * @link         https://codecanyon.net/item/wordpress-demo-content-manager/20669604
 * @copyright    Copyright (C) 2018 Torbara (http://torbara.com). All rights reserved.
 * @license      Envato Standard License http://themeforest.net/licenses/standard?ref=torbara
 * @author       Vladislav Dolgolenko <vladislavdolgolenko.com>
 * @support      <help@vladislavdolgolenko.com>
 */

namespace DM;

use DM\Service;
use DM\Config;

class Data
{
    static $file_handle = null;
    
    static public function getActivateDemo()
    {
        global $table_prefix;
        return $table_prefix; 
    }
    
    static public function setData($key, $value)
    {
        self::fopen();
        $data = self::read();
        $site_key = self::getDataKey();
        
        if (!isset($data[$site_key]) || !is_array($data[$site_key])) {
            $data[$site_key] = array();
        }
        
        $data[$site_key][$key] = $value;
        self::write($data);
        self::fclose();
    }
   

    static public function getData($key = null)
    {
        self::fopen();
        $all_data = self::read();
        self::fclose();
        
        $site_key = self::getDataKey();
        if (!isset($all_data[$site_key])) {
            $data = array();
        } else {
            $data = $all_data[$site_key];
        }
        
        if ($key) {
            return isset($data[$key]) ? $data[$key] : null;
        } else {
            return $data;
        }
    }
    
    static public function getDataKey()
    {
        $site_key = Service::getDBname();
        if (!$site_key) {
            self::fclose();
            throw new \Exception('Save data error. Undefined DataBase name!');
        }
        
        return $site_key;
    }

    static public function read()
    {
        $data_json_content = implode('', \file(self::getFilePath()));
        $all_data = json_decode($data_json_content ? $data_json_content : '{}', true);
        return $all_data;
    }
    
    static public function write($array)
    {
        \ftruncate(self::$file_handle, 0);
        \fwrite(self::$file_handle, json_encode($array, JSON_PRETTY_PRINT));
    }
    
    static public function fopen()
    {
        self::$file_handle = fopen(self::getFilePath(), 'c+');
        \flock(self::$file_handle, LOCK_EX); 
    }
    
    static public function fclose()
    {
        if (self::$file_handle) {
            \fclose(self::$file_handle);
        }
    }
    
    static public function getFilePath()
    {
        $file_path = Config::getInstance()->getDataPath();
        return $file_path;
    }
}

