<?php

/**
 * @encoding     UTF-8
 * @package      WordPress Demo Content Manager
 * @link         https://codecanyon.net/item/wordpress-demo-content-manager/20669604
 * @copyright    Copyright (C) 2018 Torbara (http://torbara.com). All rights reserved.
 * @license      Envato Standard License http://themeforest.net/licenses/standard?ref=torbara
 * @author       Vladislav Dolgolenko <vladislavdolgolenko.com>
 * @support      <help@vladislavdolgolenko.com>
 */

namespace DM;

use DM\Data;
use DM\Service;
use DM\Config;

class Demo
{
    protected $id = null;
    protected $screenshot_url = null;
    protected $name = null;
    protected $description = null;
    protected $preview_link = null;
    protected $market_link = null;
    protected $upload_url = null;
    protected $site_url = null;
    protected $uploads_url = null;
    protected $template_name = null;
    protected $template_version = null;
    protected $status = null;
    protected $upload_size = null;
    protected $plugins = null;
    protected $tags = null;
    protected $date_creation = null;
    public $version = null;
    
    public function __construct($data = array())
    {
        $this->exchangeArray($data);
    }
    
    public function exchangeArray($data)
    {
        $this->id = isset($data['id']) ? $data['id'] : null;
        $this->screenshot_url = isset($data['screenshot_url']) ? $data['screenshot_url'] : null;
        $this->name = isset($data['name']) ? $data['name'] : null;
        $this->description = isset($data['description']) ? $data['description'] : null;
        $this->preview_link = isset($data['preview_link']) ? $data['preview_link'] : null;
        $this->market_link = isset($data['market_link']) ? $data['market_link'] : null;
        $this->upload_url = isset($data['upload_url']) ? $data['upload_url'] : null;
        $this->site_url = isset($data['site_url']) ? $data['site_url'] : null;
        $this->uploads_url = isset($data['uploads_url']) ? $data['uploads_url'] : null;
        $this->template_name = isset($data['template_name']) ? $data['template_name'] : null;
        $this->template_version = isset($data['template_version']) ? $data['template_version'] : null;
        $this->status = isset($data['status']) ? $data['status'] : null;
        $this->upload_size = isset($data['upload_size']) ? $data['upload_size'] : null;
        $this->plugins = isset($data['plugins']) ? $data['plugins'] : null;
        $this->tags = isset($data['tags']) ? $data['tags'] : null;
        $this->version = isset($data['version']) ? $data['version'] : false;
        $this->date_creation = isset($data['date_creation']) ? $data['date_creation'] : false;
    }
    
    public function toArray()
    {
        return array(
            'id' => $this->id,
            'date_creation' => $this->date_creation,
            'template_version' => $this->template_version,
            'template_name' => $this->template_name,
            'site_url' => $this->site_url,
            'name' => $this->name,
            'status' => $this->status,
            'upload_size' => $this->upload_size,
            'plugins' => $this->plugins,
            'tags' => $this->tags,
            'screenshot_url' => $this->screenshot_url,
            'preview_link' => $this->preview_link,
            'market_link' => $this->market_link,
            'upload_url' => $this->upload_url,
            'uploads_url' => $this->uploads_url,
            'description' => $this->description,
        );
    }
    
    public function getGlobalId()
    {
        return $this->version . '&' . $this->getId();
    }
    
    public function getId()
    {
        return $this->id;
    }
    
    public function setId($id)
    {
        $this->id = $id;
    }
    
    public function getDateCreation()
    {
        return $this->date_creation;
    }
    
    public function setDataCreation($int)
    {
        $this->date_creation = $int;
    }
    
    public function getTitle()
    {
        return $this->name;
    }
    
    public function setTitle($string)
    {
        $this->name = $string;
    }
    
    public function getDescription()
    {
        return $this->description;
    }
    
    public function getScreenshotUrl()
    {
        return $this->screenshot_url;
    }
    
    public function getPreviewLink()
    {
        return $this->preview_link;
    }
    
    public function getUploadUrl()
    {
        if ($this->isComingSoon()) {
            return '';
        }
        
        if (!$this->upload_url) {
            return Config::getInstance()->getUploadDemoUrl( $this->getId(), $this->getDateCreation() );
        }
        
        return $this->upload_url;
    }
    
    public function getTablePrefix()
    {
        return $this->getId();
    }
    
    public function setSiteUrl($url)
    {
        $this->site_url = $url;
    }
            
    public function getSiteUrl()
    {
        return $this->site_url;
    }
    
    public function setUploadsUrl($url)
    {
        $this->uploads_url = $url;
    }
            
    public function getUploadsUrl()
    {
        return $this->uploads_url;
    }
    
    public function getTemplateName()
    {
        return $this->template_name;
    }
    
    public function setTemplateName($string)
    {
        $this->template_name = $string;
    }
    
    public function getTemplateVersion()
    {
        return $this->template_version;
    }
    
    public function setTemplateVersion($string)
    {
        $this->template_version = $string;
    }
    
    public function getStatus()
    {
        return $this->status;
    }
    
    public function setStatus($int)
    {
        $this->status = $int;
    }
    
    public function getTags()
    {
        return $this->tags;
    }
    
    public function setTags($string)
    {
        $this->tags = $string;
    }
    
    public function getPlugins()
    {
        return $this->plugins;
    }
    
    public function setPlugins($string)
    {
        $this->plugins = $string;
    }
    
    public function getMarketLink()
    {
        return $this->market_link;
    }
    
    public function setMarketLink($string)
    {
        $this->market_link = $string;
    }
    
    public function getUploadSize()
    {
        return $this->upload_size;
    }
    
    public function setUploadSize($int)
    {
        $this->upload_size = (int)$int;
    }
    
    public function getStructureSql()
    {
        $wp_filesystem = \DM\WPObjects\FileSystem\FileSystem::getInstance();
        
        $structure_file_name = $this->getDbDir() . "/structure.sql";
        return $wp_filesystem->get_contents($structure_file_name);
    }
    
    /**
     * Return escaping html strings in array if warning exists
     * @since 2.0.3
     * @return array
     */
    public function getNotices()
    {
        $required_plugins = $this->getPluginsRequired();
        $result = array();
        if (!$this->isCurrentThemeDemo()) { 
                $string = '<i class="fa fa-exclamation-triangle" aria-hidden="true"></i>';
                $string .= sprintf(esc_html__('This demo required theme %s', 'dm'), $this->getTemplateName());
                $result[] = $string;
        } else if (!$this->isCompatibleCurrentThemeVersion()) {
                $string = '<i class="fa fa-exclamation-triangle" aria-hidden="true"></i>';
                $string .= sprintf(esc_html__('Your template must be version %s or higher.', 'dm'), $this->getTemplateVersion()); 
                $result[] = $string;
        } else if ($required_plugins) {
                $string = '<i class="fa fa-exclamation-triangle" aria-hidden="true"></i>';
                $string .= sprintf(esc_html__('Next plugins must be installed: %s.', 'dm'), implode(', ', $required_plugins));
                $result[] = $string;
        }

        if ($this->version === \DM\Manager::REMOUTE && !$this->isHaveFreeDiskSpace()) {
            $string = '<i class="fa fa-exclamation-triangle" aria-hidden="true"></i>';
            $result .= sprintf(esc_html__('Not enough free space (total: %s MB), you need at least %s MB or higher.', 'dm'), \DM\Service::getFreeSpace(), $this->getMinFreeSpaceSize()); 
            $result[] = $string;
        }
        
        return $result;
    }
    
    public function isUploaded()
    {
        $wp_filesystem = \DM\WPObjects\FileSystem\FileSystem::getInstance();
        
        if ($wp_filesystem->is_dir( $this->getDemoDir() )) {
            return true;
        }
        
        return false;
    }
    
    public function isRemoute()
    {
        if ($this->remoute === true) {
            return true;
        }
        
        return false;
    }
    
    public function isComingSoon()
    {
        if ($this->getStatus() == "coming-soon") {
            return true;
        }
        
        return false;
    }
    
    public function isActivated()
    {
        if (Data::getActivateDemo() == $this->getId()) {
            return true;
        }
        
        return false;
    }
    
    public function isInstalled()
    {
        if ($this->hasDatabaseTables() === true) {
            return true;
        }
        
        return false;
    }
    
    public function hasDatabaseTables()
    {
        global $wpdb;
        $tables = $this->getTablesList();
        $prefix = $this->getTablePrefix();
        $db_tables = $wpdb->get_col("SHOW TABLES;");
        
        foreach ($tables as $table_name) {
            $full_table_name = $prefix . $table_name;
            if (!in_array($full_table_name, $db_tables)) {
                return $full_table_name;
            }
        }
        
        return true;
    }
    
    public function isCurrentThemeDemo()
    {
        if ($this->getTemplateName() == Service::getCurrentTheme()->get('TextDomain')) {
            return true;
        }
        
        return false;
    }
    
    public function isCompatibleCurrentThemeVersion()
    {
        if ($this->getTemplateVersion() == "*") {
            return true;
        }
        
        $demo_vesrion_value = explode(".", $this->getTemplateVersion());
        $theme_version_value = explode(".", Service::getCurrentTheme()->Version);
        
        foreach ($theme_version_value as $pos => $value) {
            $demo_value = $demo_vesrion_value[$pos];
            if ($demo_value == "*") {
                continue;
            }
            
            if ((int)$value < (int)$demo_value) {
                return false;
            } elseif ((int)$value > (int)$demo_value) {
                return true;
            }
        }
        
        return true;
    }
    
    public function isHaveFreeDiskSpace()
    {
        $upload_size = $this->getMinFreeSpaceSize();
        if (!$upload_size) {
            return true;
        }
        
        $free_space = Service::getFreeSpace();
        if (!$free_space) {
            return true;
        }
        
        if ($free_space < $upload_size) {
            return false;
        }
        
        return true;
    }
    
    public function getPluginsRequired()
    {
        $plugins = str_replace(' ', '', $this->getPlugins());
        if (!$plugins) {
            return;
        }
        $plugins_names = explode(',', $plugins);
        
        $all_plugins = get_plugins();
        $installed = array();
        foreach ($all_plugins as $file_patch => $details) {
            if (isset($details['TextDomain']) && $details['TextDomain']) {
                $name = $details['TextDomain'];
            } else {
                $file_patches = explode('/', $file_patch);
                $name  = $file_patches[0];
            }
            
            if (in_array($name, $plugins_names)) {
                $installed[] = $name;
            }
        }
        
        $diff = array_diff($plugins_names, $installed);
        if (count($diff) > 0) {
            return $diff;
        }
        
        return false;
    }
    
    public function getMinFreeSpaceSize()
    {
        $upload_size = $this->getUploadSize();
        if (!$upload_size) {
            return false;
        }
        
        return (int) $upload_size * 2.1;
    }
    
    public function getLocalConfigFilePath()
    {
        return $this->getDemoDir() . 'config.json';
    }
    
    public function getDemoDir()
    {
        return Config::getInstance()->getDemosDir() . $this->getId() . '/';
    }
    
    public function getUploadsDir()
    {
        return Config::getInstance()->getDemosDir() . $this->getId() . '/uploads';
    }
    
    public function getPluginsDir()
    {
        return Config::getInstance()->getDemosDir() . $this->getId() . '/plugins';
    }
    
    public function getDbDir()
    {
        return Config::getInstance()->getDemosDir() . $this->getId() . '/db';
    }
    
    public function getTablesList()
    {
        $wp_filesystem = \DM\WPObjects\FileSystem\FileSystem::getInstance();
        $result = array();
        
        if ($wp_filesystem->is_dir($this->getDbDir()) === false) {
            return array( 'posts', 'comments', 'links', 'options', 'postmeta', 'terms', 'term_taxonomy', 'term_relationships', 'termmeta', 'commentmeta' );
        }
        
        $files_list = $wp_filesystem->dirlist($this->getDbDir());
        foreach ($files_list as $file_name => $details) {
            if (preg_match("/json/", $file_name) === 1) {
                $result[] = str_replace('.json', "", $file_name);
            }
        }
        
        return $result;
    }
    
    public function isZipping()
    {
        if (!file_exists($this->getDemoZipFilePath())) {
            return false;
        }
        
        return true;
    }
    
    public function getDemoZipFileUrl()
    {
        return \content_url()  . '/wp_demo_manager/dumps/' . $this->getDemoZipFileName();
    }
    
    public function getDemoZipFilePath()
    {
        return Config::getInstance()->getDemosDir() . $this->getDemoZipFileName();
    }
    
    public function getDemoZipFileName()
    {
        return $this->getId() . '.zip';
    }
    
    /**
     *  Upload to local store demo content from repository
     */
    public function upload()
    {
        $wp_filesystem = \DM\WPObjects\FileSystem\FileSystem::getInstance();
        
        $dump_dir = Config::getInstance()->getDemosDir();
        if (!$wp_filesystem->is_dir($dump_dir) && !wp_mkdir_p($dump_dir)) {
            throw new \Exception("No permission to create a directory");
        }
        
        $url = $this->getUploadUrl();
        $url_filename = basename( parse_url( $url, PHP_URL_PATH ) );
        $temp_filename = wp_tempnam( $url_filename );
        $response = wp_remote_get( $url, array( 'timeout' => '600', 'stream' => true, 'filename' => $temp_filename ) );
        if ($response instanceof \WP_Error || !$wp_filesystem->exists($temp_filename)) {
            throw new \Exception('Error with uploading demo files from: '. $url);
        }
        
        unzip_file($temp_filename, $dump_dir);
        $wp_filesystem->delete($temp_filename);
        
        if (!$this->isUploaded()) {
            throw new \Exception('Error with unzip demo files.');
        }
    }
    
    /**
     * Remove demo content from local store
     */
    public function remove()
    {
        $wp_filesystem = \DM\WPObjects\FileSystem\FileSystem::getInstance();

        $dir_path = $this->getDemoDir();
        if ($wp_filesystem->is_dir($dir_path)) {
            return $wp_filesystem->rmdir($dir_path, true);
        }
        
        return true;
    }
}

