<?php

/**
 * @encoding     UTF-8
 * @package      WordPress Demo Content Manager
 * @link         https://codecanyon.net/item/wordpress-demo-content-manager/20669604
 * @copyright    Copyright (C) 2018 Torbara (http://torbara.com). All rights reserved.
 * @license      Envato Standard License http://themeforest.net/licenses/standard?ref=torbara
 * @author       Vladislav Dolgolenko <vladislavdolgolenko.com>
 * @support      <help@vladislavdolgolenko.com>
 */

namespace DM\Processing;

use DM\Data;

/**
 * Installation status controle
 * Statuses constants
 */
class Statuses
{
    private static $_instance = null;
    private static $TmpFileHandler = null;
    
    public function __construct(){}
    
    /**
     * @return Statuses
     */
    static public function getInstance()
    {
        if (is_null(self::$_instance)) {
            self::$_instance = new self();
        }
        
        return self::$_instance;
    }
    
    public function clean()
    {
        $this->setProcessingStepsCount(null);
        $this->changeStatus(null);
        $this->setProcessingDemoId(null);
        $this->setProcessName(null);
        $this->setProcessId(null);
    }
    
    public function setProcessName($string)
    {
        Data::setData('process_name', $string);
    }
    
    public function getProcessName()
    {
        return Data::getData('process_name');
    }
    
    public function setProcessId($string)
    {
        Data::setData('process_id', $string);
    }
    
    public function getProcessId()
    {
        return Data::getData('process_id');
    }
    
    public function getProcessingDemoId()
    {
        return Data::getData('processing_demo');
    }
    
    public function setProcessingDemoId($int)
    {
        Data::setData('processing_demo', $int);
    }
    
    public function getProcessingStepsCount()
    {
        return Data::getData('processing_steps_count');
    }
    
    public function setProcessingStepsCount($int)
    {
        Data::setData('processing_steps_count', $int);
    }
    
    /**
     * @return int
     */
    public function getCurrentStatus()
    {
        return Data::getData('current_status');
    }
    
    /**
     * @return array 
     */
    public function getCurrentStatusData()
    {
        return Data::getData('current_status_data');
    }
    
    /**
     * Save status to local storage
     * @return boolean
     */
    public function changeStatus($int)
    {
        Data::setData('current_status', $int);
    }
    
    public function changeStatusData($data)
    {
        Data::setData('current_status_data', $data);
    }
    
    public function isProcessing()
    {
        $wp_filesystem = \DM\WPObjects\FileSystem\FileSystem::getInstance();
        $temp_file_path = $this->getPID();
        
        if (!$temp_file_path) {
            return false;
        }
        
        $sys_temp_dir = $this->getTmpDir();
        
        clearstatcache();
        if (is_readable( $sys_temp_dir ) !== true) {
            return true;
        }
        
        $tmp_files_list = $wp_filesystem->dirlist( $sys_temp_dir );
        if ($tmp_files_list === false) {
            return true;
        }
        
        $file_name = basename($temp_file_path);
        foreach ($tmp_files_list as $name => $options) {
            if ($name === $file_name) {
                return true;
            }
        }
                
        $this->endPID();
        return false;
    }
    
    public function createPID()
    {
        self::$TmpFileHandler = $this->createPIDFile();
        fwrite(self::$TmpFileHandler, "process runing");
        $metaDatas = stream_get_meta_data(self::$TmpFileHandler);
        $tmpFilename = $metaDatas['uri'];
        
        if (file_exists($tmpFilename) === false) {
            throw new \Exception('Process runing error: could not create process file!');
        }
        
        $this->setPID($tmpFilename);
    }
    
    public function endPID()
    {
        $temp_file_path = $this->getPID();
        $this->setPID(null);
        
        if (file_exists($temp_file_path)) {
            @unlink($temp_file_path);
        }
        
        return $this;
    }
    
    /**
     * @return resource a file pointer resource on success
     */
    protected function createPIDFile()
    {
        if ($this->hasSysTmpDir()) {
            return \tmpfile();
        }
        
        $dir = $this->getTmpDir();
        $file_path =  $dir . DIRECTORY_SEPARATOR . 'dm_process_' . time();
        $filehandler = fopen($file_path, 'w+');
        return $filehandler;
    }
    
    protected function getTmpDir()
    {
        if ($this->hasSysTmpDir()) {
            return \sys_get_temp_dir();
        }
        
        $uploads_dir_info = \wp_upload_dir();
        return $uploads_dir_info['basedir'];
    }
    
    protected function hasSysTmpDir()
    {
        $sys_temp_dir = sys_get_temp_dir();
        if (is_dir($sys_temp_dir) && is_readable($sys_temp_dir) && is_writable($sys_temp_dir)) {
            return true;
        }
        
        return false;
    }
    
    public function getPID()
    {
        return Data::getData('pid');
    }
    
    public function setPID($pid)
    {
        Data::setData('pid', $pid);
    }
}

