<?php

/**
 * @encoding     UTF-8
 * @package      WordPress Demo Content Manager
 * @link         https://codecanyon.net/item/wordpress-demo-content-manager/20669604
 * @copyright    Copyright (C) 2018 Torbara (http://torbara.com). All rights reserved.
 * @license      Envato Standard License http://themeforest.net/licenses/standard?ref=torbara
 * @author       Vladislav Dolgolenko <vladislavdolgolenko.com>
 * @support      <help@vladislavdolgolenko.com>
 */

namespace DM\Processing;

abstract class Step
{
    protected $step_status = null;
    
    /**
     * @var dm_Log
     */
    protected $Log = null;
    
    /**
     * @var dm_Demo
     */
    protected $Demo = null;
    
    /**
     * @var wpdb
     */
    protected $wpdb = null;
    
    /**
     * @var Statuses
     */
    protected $Statuses = null;
    
    /**
     * @var \DM\Processing\AbstractProcess 
     */
    protected $Process = null;
    
    public function __construct(\DM\Log $Log, $Demo)
    {
        global $wpdb;
        
        $this->wpdb = $wpdb;
        $this->Log = $Log;
        $this->Demo = $Demo;
        $this->Statuses = Statuses::getInstance();
    }
    
    /**
     * Step controlling
     * @return boolean
     */
    public function doStep()
    {
        if (is_null($this->step_status)) {
            throw new \Exception('Development error: step status not setted!' . $this->step_status);
        }
        
        $current_step_status = $this->getStatuses()->getCurrentStatus();
        if (!is_numeric($current_step_status)) {
            $current_step_status = $this->step_status - 1;
            $this->getStatuses()->changeStatus($current_step_status);
        }
        
        if ($this->step_status <= $current_step_status) {
            return true;
        }
        
        if($this->processing() !== true) {
            return false;
        }
        
        $this->getStatuses()->changeStatus($this->step_status);
        $this->getStatuses()->changeStatusData(array());
        
        //throw new \Exception('Error: opps');
        
        return true;
    }
    
    abstract protected function processing();
    
    public function doAbort()
    {
        if (is_null($this->step_status)) {
            throw new \Exception('Development error: step status not setted!' . $step_status);
        }
        
        $current_step_status = $this->getStatuses()->getCurrentStatus();
        if (!is_numeric($current_step_status)) {
            $current_step_status = $this->step_status + 1;
            $this->getStatuses()->changeStatus($current_step_status);
        }
        
        if ($this->step_status > $current_step_status) {
            return true;
        }
        
        if($this->abort() !== true) {
            return false;
        }
        
        $this->getStatuses()->changeStatus($this->step_status - 1);
        $this->getStatuses()->changeStatusData(array());
        
        //throw new \Exception('Error: opps');
        
        return true;
    }
    
    abstract protected function abort();

    /**
     * @return \DM\Log
     */
    protected function getLog()
    {
        return $this->Log;
    }
    
    /**
     * @return \DM\Demo
     */
    protected function getDemo()
    {
        return $this->Demo;
    }
    
    /**
     * @return wpdb
     */
    public function getDB()
    {
        return $this->wpdb;
    }
    
    /**
     * @return \DM\Processing\Statuses
     */
    public function getStatuses()
    {
        return $this->Statuses;
    }
    
    public function setStepStatus($int)
    {
        $this->step_status = $int;
    }
    
    public function getStepStatus()
    {
        return $this->step_status;
    }
    
    public function setProcess(\DM\Processing\AbstractProcess $Process)
    {
        $this->Process = $Process;
    }
    
    /**
     * @return \DM\Processing\AbstractProcess
     */
    public function getProcess()
    {
        return $this->Process;
    }
}

