<?php

/**
 * @encoding     UTF-8
 * @package      WordPress Demo Content Manager
 * @link         https://codecanyon.net/item/wordpress-demo-content-manager/20669604
 * @copyright    Copyright (C) 2018 Torbara (http://torbara.com). All rights reserved.
 * @license      Envato Standard License http://themeforest.net/licenses/standard?ref=torbara
 * @author       Vladislav Dolgolenko <vladislavdolgolenko.com>
 * @support      <help@vladislavdolgolenko.com>
 */

namespace DM\Processing\Steps;

use DM\Processing\Step;
use DM\Service;

class CreateDbDataJsonDump extends Step
{
    protected $table_prefix_filtered = array(
        'options' => 'option_name',
        'usermeta' => 'meta_key'
    );
    
    /**
     * @return boolean
     * @throws Exception
     */
    protected function processing()
    {
        $this->getLog()->addLog('Creating database tables dumps');
        $this->createDBDump();
        
        return true;
    }
    
    /**
     *  Выбираем таблицы
     *  Создаем дамп
     *  Сохраняем файл
     */
    public function createDBDump()
    {
        $wp_filesystem = \DM\WPObjects\FileSystem\FileSystem::getInstance();
        $tables = Service::getCurrentWordpressDbTables( $this->getOriginTablePrefix() );
        $db_dir_name = $this->getDemo()->getDbDir();
        
        if (!is_dir($db_dir_name)) {
            wp_mkdir_p($db_dir_name);
        }
        
        foreach ($tables as $clear_name => $name) {
            $table_json = $this->getTableJson($name); 
            $wp_filesystem->put_contents($db_dir_name . "/$clear_name.json", $table_json);
        }
        
        return true;
    }
    
    /**
     * Выбираем все строки таблицы, сервиализируем в JSON и десириализируем PHP обекты
     * @param string $table_name
     * @return json
     */
    public function getTableJson($table_name)
    {
        $result_rows = array();
        $query_sql = "SELECT * FROM $table_name";
        $rows = $this->getDB()->get_results($query_sql, "ARRAY_A");
        $origin_prefix = $this->getOriginTablePrefix();
        $wp_table_name = str_replace($origin_prefix, '', $table_name);
        
        foreach ($rows as $origin_row) {
            
            // Clear row with temporary data
            if ($this->isConfirmRow($origin_row) === false) {
                continue;
            }
            
            $row = $this->filterTablePrefix($wp_table_name, $origin_row);
            
            $result_row = array();
            
            foreach ($row as $key => $value) {
                $result_value = null;
                if (is_serialized($value)) {
                    $result_value = unserialize($value);
                } else {
                    $result_value = $value;
                }
                
                $result_row[$key] = $result_value;
            }
            
            $result_rows[] = $result_row;
        }
        
        return json_encode($result_rows);
    }
    
    /**
     * Detected cache and trainsient data rows
     * @param array $row
     */
    public function isConfirmRow($row)
    {
        foreach ($row as $key => $value) {
            if ($key == "option_name" && stripos($value, 'transient') !== false) {
                return false;
            }
            if ($key == "option_name" && stripos($value, 'wp_less_cached') !== false) {
                return false;
            }
        }
        
        return true;
    }
    
    public function filterTablePrefix($table_name, $row)
    {
        if (!in_array($table_name, array_keys($this->table_prefix_filtered))) {
            return $row;
        }
        
        $origin_prefix = $this->getOriginTablePrefix();
        $demo_prefix = $this->getDemo()->getTablePrefix();
        
        $col_name = $this->table_prefix_filtered[$table_name];
        foreach ($row as $key => $value) {
            if ($col_name !== $key) {
                continue;
            }
            
            $row[$key] = str_replace($origin_prefix, $demo_prefix, $value);
        }
        
        return $row;
    }
    
    public function getOriginTablePrefix()
    {
        global $table_prefix;
        return $table_prefix;
    }
    
    protected function abort()
    {
        return true;
    }
}

