<?php

/**
 * @encoding     UTF-8
 * @package      WordPress Demo Content Manager
 * @link         https://codecanyon.net/item/wordpress-demo-content-manager/20669604
 * @copyright    Copyright (C) 2018 Torbara (http://torbara.com). All rights reserved.
 * @license      Envato Standard License http://themeforest.net/licenses/standard?ref=torbara
 * @author       Vladislav Dolgolenko <vladislavdolgolenko.com>
 * @support      <help@vladislavdolgolenko.com>
 */

$MainPage = \DM\Pages\DemoManager::getInstance();
$DMConfig = \DM\Config::getInstance();

?>

<div class="bootstrap-wrapper demo-manager">
    <div class="container-fluid">
        <div class="row header">
            <div class="col-lg-6">
                <h1>
                    <img 
                        src="<?php echo plugins_url() . '/wp_demo_manager/assets/images/dm_logo.png'; ?>" 
                        class="logo"
                    >
                    <?php esc_html_e('Settings', 'dm')?>
                </h1>
            </div>
            <div class="clearfix"></div>
        </div>
        
        <?php if (!$DMConfig->isDevelopMode()): ?>
        <div class="row">
            <div class="col-lg-12">
                    
                <div class="settings">
                    <h3><?php esc_html_e('Develop mode', 'dm');?></h3>
                    <form class="" method="POST">
                        <div class="row">
                            <div class="col-lg-6">
                                <div class="form-group">
                                    <div class="checkbox">
                                        <input type="hidden" name="enable_develop_mod">
                                        <input type="checkbox" name="enable_develop_mod" value="1" <?php echo \DM\Data::getData('enable_develop_mod') ? 'checked' : '';?>>
                                        <?php esc_html_e('Enable develope tools', 'dm');?>
                                    </div>
                                </div>
                                <div class="form-group">
                                    <button type="submit" class="btn btn-default">
                                        <?php esc_html_e('Save changes', 'dm');?>
                                    </button>
                                </div>
                            </div>
                            <div class="clearfix"></div>
                        </div>
                    </form>
                </div>
                
                <div class="clearfix"></div>
            </div>
            <div class="clearfix"></div>
        </div>
        
        <?php else: ?>
        
        <div class="row">
            <div class="col-lg-12">
                    
                    <div class="settings">
                        <h3><?php esc_html_e('Remoute repository settings', 'dm');?></h3>

                        <form class="" method="POST">
                            <div class="row">
                                <div class="col-lg-6">
                                    <div class="form-group">
                                    <label for="repository_url"><?php esc_html_e('Repository url', 'dm');?></label>
                                    <input type="text" class="form-control" name="repository_url" placeholder="http://cdn.example.com/repository/" value="<?php echo esc_html(\DM\Data::getData('repository_url'));?>">
                                    <?php if ($default = $DMConfig->getDefaultValue('repository_url')) : ?>
                                        <p class="help-block"><?php esc_html_e('Default', 'dm');?>: <b><?php echo esc_html($default); ?></b></p>
                                    <?php endif; ?>
                                    </div>
                                </div>
                                <div class="col-lg-6">
                                    <div class="form-group">
                                    <label for="repository_library_name"><?php esc_html_e('Repository library name', 'dm');?></label>
                                    <input type="text" class="form-control" name="repository_library_name" placeholder="Example library" value="<?php echo esc_html(\DM\Data::getData('repository_library_name'));?>">
                                    <?php if ($default = $DMConfig->getDefaultValue('repository_library_name')) : ?>
                                        <p class="help-block"><?php esc_html_e('Default', 'dm');?>: <b><?php echo esc_html($default); ?></b></p>
                                    <?php endif; ?>
                                    </div>
                                </div>
                                <div class="col-lg-12">
                                    <div class="form-group">
                                    <label for="ftp_host"><?php esc_html_e('FTP host', 'dm');?></label>
                                    <input type="text" class="form-control" name="ftp_host" placeholder="cdn.example.com" value="<?php echo esc_html(\DM\Data::getData('ftp_host'));?>">
                                    </div>
                                </div>
                                <div class="col-lg-6">
                                    <div class="form-group">
                                    <label for="ftp_user"><?php esc_html_e('FTP user', 'dm');?></label>
                                    <input type="text" class="form-control" name="ftp_user" placeholder="root" value="<?php echo esc_html(\DM\Data::getData('ftp_user'));?>">
                                    </div>
                                </div>
                                <div class="col-lg-6">
                                    <div class="form-group">
                                    <label for="ftp_password"><?php esc_html_e('FTP password', 'dm');?></label>
                                    <input type="password" class="form-control" name="ftp_password" placeholder="123456" value="<?php echo esc_html(\DM\Data::getData('ftp_password'));?>">
                                    </div>
                                </div>
                                <div class="col-lg-12">
                                    <div class="form-group">
                                    <button type="submit" class="btn btn-default">
                                        <?php esc_html_e('Save changes', 'dm');?>
                                    </button>
                                    </div>
                                </div>
                                <div class="clearfix"></div>
                            </div>
                        </form>
                    </div>
                    
                    <div class="settings">
                        <h3><?php esc_html_e('Auto update demo content from repository', 'dm');?></h3>
                        <p class="text-warning"><?php esc_html_e('Use this options only if current wordpress site is demo preview and you need conformity 1:1 with demo version in repository.', 'dm');?></p>
                        <?php if ($example_demo_id = \DM\Data::getData('origin_demo_id')): ?>
                            <p class="text-success">
                                <?php echo sprintf(__('Current wordpress site will be conformation to demo %s. Now any actions with content on the current site will be deleted when updating the demo, please be careful.'), $example_demo_id) ?>
                            </p>
                        <?php endif; ?>
                        <form class="" method="POST">
                            <div class="row">
                                <div class="col-lg-6">
                                    <div class="form-group">
                                        <label for="origin_demo_id"><?php esc_html_e('Demo id', 'dm');?></label>
                                        <input type="text" class="form-control" name="origin_demo_id" placeholder="example_demo_id" value="<?php echo esc_html(\DM\Data::getData('origin_demo_id'));?>">
                                        <p class="help-block"><?php esc_html_e('Set the demo id for auto reinstalled when version of demo content updating in repository', 'dm');?></p>
                                    </div>
                                </div>
                                <div class="col-lg-12">
                                    <div class="form-group">
                                        <button type="submit" class="btn btn-default">
                                            <?php esc_html_e('Save changes', 'dm');?>
                                        </button>
                                    </div>
                                </div>
                                <div class="clearfix"></div>
                            </div>
                        </form>
                    </div>
                    
                    <div class="settings">
                        <h3><?php esc_html_e('Statistic reports settings', 'dm');?></h3>
                        <form class="" method="POST">
                            <div class="row">
                                <div class="col-lg-6">
                                    <div class="form-group">
                                        <label for="statistic_post_report_url"><?php esc_html_e('POST method url', 'dm');?></label>
                                        <input type="text" class="form-control" name="statistic_post_report_url" placeholder="http://example.com/statistic.php" value="<?php echo esc_html(\DM\Data::getData('statistic_post_report_url'));?>">
                                        <?php if ($default = $DMConfig->getDefaultValue('statistic_post_report_url')) : ?>
                                        <p class="help-block"><?php esc_html_e('Default', 'dm');?>: <b><?php echo esc_html($default); ?></b></p>
                                        <?php endif; ?>
                                    </div>
                                </div>
                                <div class="col-lg-12">
                                    <div class="form-group">
                                        <button type="submit" class="btn btn-default">
                                            <?php esc_html_e('Save changes', 'dm');?>
                                        </button>
                                    </div>
                                </div>
                                <div class="clearfix"></div>
                            </div>
                        </form>
                    </div>
                    
                    <div class="settings">
                        <h3><?php esc_html_e('Develop mode', 'dm');?></h3>
                        <form class="" method="POST">
                            <div class="row">
                                <div class="col-lg-6">
                                    <div class="form-group">
                                        <div class="checkbox">
                                            <input type="hidden" name="enable_develop_mod">
                                            <input type="checkbox" name="enable_develop_mod" value="1" <?php echo \DM\Data::getData('enable_develop_mod') ? 'checked' : '';?>>
                                            <?php esc_html_e('Enable develope tools', 'dm');?>
                                        </div>
                                    </div>
                                    <div class="form-group">
                                        <button type="submit" class="btn btn-default">
                                            <?php esc_html_e('Save changes', 'dm');?>
                                        </button>
                                    </div>
                                </div>
                                <div class="col-lg-6">
                                    <?php if ($DMConfig->getDefaultValue('enable_develop_mod')) : ?>
                                    <p class="text-success"><?php esc_html_e('Enabled as defaults setting in source code', 'dm');?></p>
                                    <pre>
\DM\Config::getInstance()->setDefaults(
    array(
        'enable_develop_mod' => true
    )
);
                                    </pre>
                                    <?php endif; ?>
                                </div>
                                
                                <div class="clearfix"></div>
                            </div>
                        </form>
                    </div>
                    
                    
                    <div class="settings">
                        <h3><?php esc_html_e('Multisite mode', 'dm');?></h3>
                        <form class="" method="POST">
                            <div class="row">
                                <div class="col-lg-6">
                                    <div class="form-group">
                                        <div class="checkbox">
                                            <input type="hidden" name="enable_multisite_mode">
                                            <input type="checkbox" name="enable_multisite_mode" value="1" <?php echo \DM\Data::getData('enable_multisite_mode') ? 'checked' : '';?>>
                                            <?php esc_html_e('Enable multisite demos mode', 'dm');?>
                                        </div>
                                    </div>
                                    <div class="form-group">
                                        <button type="submit" class="btn btn-default">
                                            <?php esc_html_e('Save changes', 'dm');?>
                                        </button>
                                    </div>
                                </div>
                                <div class="col-lg-6">
                                     <?php if ($DMConfig->getDefaultValue('enable_multisite_mode')) : ?>
                                    <p class="text-success "><?php esc_html_e('Enabled as defaults setting in source code', 'dm');?></p>
                                    <pre>
\DM\Config::getInstance()->setDefaults(
    array(
        'enable_multisite_mode' => true
    )
);
                                    </pre>
                                    <?php endif; ?>
                                    
                                    <?php if ($DMConfig->isMultiSite()) : ?>
                                    <p><?php esc_html_e('Add this code to begining wp-config.php', 'dm');?></p>
                                    <pre>
$http_host_vars = explode('.', $_SERVER['HTTP_HOST']);
$domain_db_name  = str_replace("-", "_", $http_host_vars[0]);

define( 'WP_DEMO_MANAGER_LOCAL_PATH', dirname(__FILE__) . '/wp-content/wp_demo_manager/' );
require dirname(__FILE__) . '/wp-content/plugins/wp_demo_manager/includes/DM/Service.php';
$domain_prefix = \DM\Service::getMultisiteCurrentTablePrefix($domain_db_name);
                                    </pre>
                                    <p><?php esc_html_e('Change table prefix declaration in wp-config.php', 'dm');?></p>
                                    <pre>
$table_prefix  = $domain_prefix;
                                    </pre>
                                    <?php endif; ?>
                                </div>
                                
                                <div class="clearfix"></div>
                            </div>
                        </form>
                    </div>
                    
                <div class="clearfix"></div>
            </div>
            <div class="clearfix"></div>
        </div>
        
        <?php endif; ?>
    </div>
</div>

