/**
 * @encoding     UTF-8
 * @package      WPObjects
 * @link         https://github.com/VladislavDolgolenko/WPObjects
 * @copyright    Copyright (C) 2018 Vladislav Dolgolenko
 * @license      MIT License
 * @author       Vladislav Dolgolenko <vladislavdolgolenko.com>
 * @support      <help@vladislavdolgolenko.com>
 */


(function(DM, Backbone){
    
    DM.ModelDataType = Backbone.Model.extend({
        
        urlRoot: DM.rest_url + '/data_type',
        
        getCollection: function () {
            if (this.Collection === undefined) {
                var url = this.getModelsUrl();
                this.Collection = new Backbone.Collection(null, {model: this.getModelClass()});
                this.Collection.url = url;
            }
            
            return this.Collection;
        },
        
        getModelClass: function () {
            if (!this.has('id_attr_name')) {
                throw new Error('Undefined id_attr_name in data type model! Maybe model not sync with server.');
            }
            
            var url = this.getModelsUrl();
            var attr = this.get('id_attr_name');
            
            return Backbone.Model.extend({
                idAttribute: attr,
                urlRoot: url,
                validate: this.getModelValidateFunction()
            });
        },
        
        getModelValidateFunction: function () {
            var Fields = this.get('form_fields') ? this.get('form_fields') : [];
            
            return function (attrs, options) {
                for (var i = 0; i < Fields.length; i++) {
                    var Field = Fields[i];
                    if (Field.require === false) {
                        continue;
                    }

                    var attr_id = Field.id === this.idAttribute && this.isNew() ? '_creation_id' : Field.id;

                    if (attrs[attr_id] === undefined || !attrs[attr_id]) {
                        return Field.label + ' is required attribute!';
                    }
                }
            };
        },
        
        getModelsUrl: function () {
            return DM.rest_url + '/' + this.id;
        },
        
        getMainQualifierDataType: function () {
            if (this.MainQualifierDataType !== undefined) {
                return this.MainQualifierDataType;
            }
            
            var qualifiers = this.get('qualifiers');
            if (!qualifiers || !qualifiers.length) {
                return false;
            }
            
            this.MainQualifierDataType = new DM.ModelDataType({id: qualifiers[0]});
            
            return this.MainQualifierDataType;
        },
        
        getMainQualifierAttr: function () {
            var qualifier = this.getMainQualifierDataType().id;
            var params = this.get('qualifiers_attr_names');
            if (params !== undefined && params[qualifier] !== undefined) {
                return params[qualifier];
            } else {
                return '_' + qualifier + '_id';
            }
        },
        
    });
    
})(DM, Backbone);